@@ -1,4 +1,4 @@
-# Allow users to build ge25519 values directly.
+"""Allow users to build ge25519 values directly."""
 from ge25519.ge25519 import\
     ge25519,\
     ge25519_p2, ge25519_p3, ge25519_p1p1,\
